@@ -1,7 +1,7 @@
 #include <R.h>
 #include <Rinternals.h>
 #include <math.h>
-#ifdef SUPPORT_OPENMP
+#ifdef _OPENMP
 #include <omp.h>
 #endif
 #include "randomkit.h"
